@@ -30,7 +30,7 @@ def getlimit(minutes=MINUTES):
   delay=timedelta(seconds=minutes*60)
   return actual_time-delay
 
-class RowParser(object):
+class NginxRowParser(object):
   def __init__(self,row):
     self.row=row
     try:
@@ -86,7 +86,13 @@ class RowParser(object):
     return code
 
   def get_bytes(self):
-    return self._get_val('bytes')
+    res=None
+    if self._get_val('bytes') is not None:
+      try:
+        res=int(self._get_val('bytes'))
+      except (ValueError,TypeError):      
+        pass      
+    return res
     
   def get_reffer(self):
     return self._get_val('reffer')
@@ -113,6 +119,13 @@ class RowParser(object):
       code=0
     return (len(https)==0 or code in https)
 
+class ApacheRowParser(NginxRowParser):
+  def get_float_latency(self):
+    res=super(ApacheRowParser,self).get_float_latency()
+    if res is not None:
+      res=res/1000000
+    return res
+    
 def get_short_agent(agent):
   res=''
   try:
